@@ -110,7 +110,7 @@ Examples:
   # Convert a PDF to markdown (default cloud mode)
   docstrange document.pdf
 
-  # Convert with API key for unlimited access
+  # Convert with free API key with increased limits
   docstrange document.pdf --api-key YOUR_API_KEY
 
   # Force local CPU processing
@@ -125,8 +125,9 @@ Examples:
   docstrange document.pdf --output csv  # Extract tables as CSV
 
   # Use specific model for cloud processing
-  docstrange document.pdf --api-key YOUR_KEY --model gemini
-  docstrange document.pdf --model openapi --output json
+docstrange document.pdf --model gemini
+docstrange document.pdf --model openapi --output json
+docstrange document.pdf --model nanonets --output csv
 
   # Convert a URL (works in all modes)
   docstrange https://example.com --output html
@@ -186,13 +187,13 @@ Examples:
     
     parser.add_argument(
         "--api-key",
-        help="API key for unlimited cloud access (get from https://app.nanonets.com/#/keys)"
+        help="API key for increased cloud access (get it free from https://app.nanonets.com/#/keys)"
     )
     
     parser.add_argument(
         "--model",
-        choices=["gemini", "openapi"],
-        help="Model to use for cloud processing (gemini, openapi)"
+        choices=["gemini", "openapi", "nanonets"],
+        help="Model to use for cloud processing (gemini, openapi, nanonets)"
     )
     
     parser.add_argument(
@@ -321,7 +322,7 @@ Examples:
         if result["success"]:
             results.append(result["result"])
             if not args.verbose:
-                print(f"✅ Processed: {input_item}", file=sys.stderr)
+                print(f"Processing ... : {input_item}", file=sys.stderr)
         else:
             errors.append(result)
             print(f"❌ Failed: {input_item} - {result['error']}", file=sys.stderr)
